Skip to main content
aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
Diffstat (limited to 'plugins/org.eclipse.etrice.core.room/src-gen/org/eclipse/etrice/core/room/impl')
-rw-r--r--plugins/org.eclipse.etrice.core.room/src-gen/org/eclipse/etrice/core/room/impl/ActorClassImpl.java76
-rw-r--r--plugins/org.eclipse.etrice.core.room/src-gen/org/eclipse/etrice/core/room/impl/DataClassImpl.java39
-rw-r--r--plugins/org.eclipse.etrice.core.room/src-gen/org/eclipse/etrice/core/room/impl/GeneralProtocolClassImpl.java123
-rw-r--r--plugins/org.eclipse.etrice.core.room/src-gen/org/eclipse/etrice/core/room/impl/RoomPackageImpl.java88
-rw-r--r--plugins/org.eclipse.etrice.core.room/src-gen/org/eclipse/etrice/core/room/impl/StructureClassImpl.java39
5 files changed, 276 insertions, 89 deletions
diff --git a/plugins/org.eclipse.etrice.core.room/src-gen/org/eclipse/etrice/core/room/impl/DataClassImpl.java b/plugins/org.eclipse.etrice.core.room/src-gen/org/eclipse/etrice/core/room/impl/DataClassImpl.java
index a5773aac8..eb28be6c6 100644
--- a/plugins/org.eclipse.etrice.core.room/src-gen/org/eclipse/etrice/core/room/impl/DataClassImpl.java
+++ b/plugins/org.eclipse.etrice.core.room/src-gen/org/eclipse/etrice/core/room/impl/DataClassImpl.java
@@ -21,6 +21,7 @@ import org.eclipse.emf.ecore.impl.ENotificationImpl;
import org.eclipse.emf.ecore.util.EObjectContainmentEList;
import org.eclipse.emf.ecore.util.InternalEList;
+import org.eclipse.etrice.core.room.Annotation;
import org.eclipse.etrice.core.room.Attribute;
import org.eclipse.etrice.core.room.DataClass;
import org.eclipse.etrice.core.room.DetailCode;
@@ -35,6 +36,7 @@ import org.eclipse.etrice.core.room.StandardOperation;
* The following features are implemented:
* <ul>
* <li>{@link org.eclipse.etrice.core.room.impl.DataClassImpl#getBase <em>Base</em>}</li>
+ * <li>{@link org.eclipse.etrice.core.room.impl.DataClassImpl#getAnnotations <em>Annotations</em>}</li>
* <li>{@link org.eclipse.etrice.core.room.impl.DataClassImpl#getUserCode1 <em>User Code1</em>}</li>
* <li>{@link org.eclipse.etrice.core.room.impl.DataClassImpl#getUserCode2 <em>User Code2</em>}</li>
* <li>{@link org.eclipse.etrice.core.room.impl.DataClassImpl#getUserCode3 <em>User Code3</em>}</li>
@@ -58,6 +60,16 @@ public class DataClassImpl extends ComplexTypeImpl implements DataClass
protected DataClass base;
/**
+ * The cached value of the '{@link #getAnnotations() <em>Annotations</em>}' containment reference list.
+ * <!-- begin-user-doc -->
+ * <!-- end-user-doc -->
+ * @see #getAnnotations()
+ * @generated
+ * @ordered
+ */
+ protected EList<Annotation> annotations;
+
+ /**
* The cached value of the '{@link #getUserCode1() <em>User Code1</em>}' containment reference.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
@@ -176,6 +188,20 @@ public class DataClassImpl extends ComplexTypeImpl implements DataClass
* <!-- end-user-doc -->
* @generated
*/
+ public EList<Annotation> getAnnotations()
+ {
+ if (annotations == null)
+ {
+ annotations = new EObjectContainmentEList<Annotation>(Annotation.class, this, RoomPackage.DATA_CLASS__ANNOTATIONS);
+ }
+ return annotations;
+ }
+
+ /**
+ * <!-- begin-user-doc -->
+ * <!-- end-user-doc -->
+ * @generated
+ */
public DetailCode getUserCode1()
{
return userCode1;
@@ -353,6 +379,8 @@ public class DataClassImpl extends ComplexTypeImpl implements DataClass
{
switch (featureID)
{
+ case RoomPackage.DATA_CLASS__ANNOTATIONS:
+ return ((InternalEList<?>)getAnnotations()).basicRemove(otherEnd, msgs);
case RoomPackage.DATA_CLASS__USER_CODE1:
return basicSetUserCode1(null, msgs);
case RoomPackage.DATA_CLASS__USER_CODE2:
@@ -380,6 +408,8 @@ public class DataClassImpl extends ComplexTypeImpl implements DataClass
case RoomPackage.DATA_CLASS__BASE:
if (resolve) return getBase();
return basicGetBase();
+ case RoomPackage.DATA_CLASS__ANNOTATIONS:
+ return getAnnotations();
case RoomPackage.DATA_CLASS__USER_CODE1:
return getUserCode1();
case RoomPackage.DATA_CLASS__USER_CODE2:
@@ -408,6 +438,10 @@ public class DataClassImpl extends ComplexTypeImpl implements DataClass
case RoomPackage.DATA_CLASS__BASE:
setBase((DataClass)newValue);
return;
+ case RoomPackage.DATA_CLASS__ANNOTATIONS:
+ getAnnotations().clear();
+ getAnnotations().addAll((Collection<? extends Annotation>)newValue);
+ return;
case RoomPackage.DATA_CLASS__USER_CODE1:
setUserCode1((DetailCode)newValue);
return;
@@ -442,6 +476,9 @@ public class DataClassImpl extends ComplexTypeImpl implements DataClass
case RoomPackage.DATA_CLASS__BASE:
setBase((DataClass)null);
return;
+ case RoomPackage.DATA_CLASS__ANNOTATIONS:
+ getAnnotations().clear();
+ return;
case RoomPackage.DATA_CLASS__USER_CODE1:
setUserCode1((DetailCode)null);
return;
@@ -473,6 +510,8 @@ public class DataClassImpl extends ComplexTypeImpl implements DataClass
{
case RoomPackage.DATA_CLASS__BASE:
return base != null;
+ case RoomPackage.DATA_CLASS__ANNOTATIONS:
+ return annotations != null && !annotations.isEmpty();
case RoomPackage.DATA_CLASS__USER_CODE1:
return userCode1 != null;
case RoomPackage.DATA_CLASS__USER_CODE2:
diff --git a/plugins/org.eclipse.etrice.core.room/src-gen/org/eclipse/etrice/core/room/impl/GeneralProtocolClassImpl.java b/plugins/org.eclipse.etrice.core.room/src-gen/org/eclipse/etrice/core/room/impl/GeneralProtocolClassImpl.java
index db8c928ce..8a37b9f73 100644
--- a/plugins/org.eclipse.etrice.core.room/src-gen/org/eclipse/etrice/core/room/impl/GeneralProtocolClassImpl.java
+++ b/plugins/org.eclipse.etrice.core.room/src-gen/org/eclipse/etrice/core/room/impl/GeneralProtocolClassImpl.java
@@ -6,8 +6,19 @@
*/
package org.eclipse.etrice.core.room.impl;
+import java.util.Collection;
+
+import org.eclipse.emf.common.notify.NotificationChain;
+
+import org.eclipse.emf.common.util.EList;
+
import org.eclipse.emf.ecore.EClass;
+import org.eclipse.emf.ecore.InternalEObject;
+
+import org.eclipse.emf.ecore.util.EObjectContainmentEList;
+import org.eclipse.emf.ecore.util.InternalEList;
+import org.eclipse.etrice.core.room.Annotation;
import org.eclipse.etrice.core.room.GeneralProtocolClass;
import org.eclipse.etrice.core.room.RoomPackage;
@@ -16,6 +27,10 @@ import org.eclipse.etrice.core.room.RoomPackage;
* An implementation of the model object '<em><b>General Protocol Class</b></em>'.
* <!-- end-user-doc -->
* <p>
+ * The following features are implemented:
+ * <ul>
+ * <li>{@link org.eclipse.etrice.core.room.impl.GeneralProtocolClassImpl#getAnnotations <em>Annotations</em>}</li>
+ * </ul>
* </p>
*
* @generated
@@ -23,6 +38,16 @@ import org.eclipse.etrice.core.room.RoomPackage;
public class GeneralProtocolClassImpl extends RoomClassImpl implements GeneralProtocolClass
{
/**
+ * The cached value of the '{@link #getAnnotations() <em>Annotations</em>}' containment reference list.
+ * <!-- begin-user-doc -->
+ * <!-- end-user-doc -->
+ * @see #getAnnotations()
+ * @generated
+ * @ordered
+ */
+ protected EList<Annotation> annotations;
+
+ /**
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
* @generated
@@ -43,4 +68,102 @@ public class GeneralProtocolClassImpl extends RoomClassImpl implements GeneralPr
return RoomPackage.Literals.GENERAL_PROTOCOL_CLASS;
}
+ /**
+ * <!-- begin-user-doc -->
+ * <!-- end-user-doc -->
+ * @generated
+ */
+ public EList<Annotation> getAnnotations()
+ {
+ if (annotations == null)
+ {
+ annotations = new EObjectContainmentEList<Annotation>(Annotation.class, this, RoomPackage.GENERAL_PROTOCOL_CLASS__ANNOTATIONS);
+ }
+ return annotations;
+ }
+
+ /**
+ * <!-- begin-user-doc -->
+ * <!-- end-user-doc -->
+ * @generated
+ */
+ @Override
+ public NotificationChain eInverseRemove(InternalEObject otherEnd, int featureID, NotificationChain msgs)
+ {
+ switch (featureID)
+ {
+ case RoomPackage.GENERAL_PROTOCOL_CLASS__ANNOTATIONS:
+ return ((InternalEList<?>)getAnnotations()).basicRemove(otherEnd, msgs);
+ }
+ return super.eInverseRemove(otherEnd, featureID, msgs);
+ }
+
+ /**
+ * <!-- begin-user-doc -->
+ * <!-- end-user-doc -->
+ * @generated
+ */
+ @Override
+ public Object eGet(int featureID, boolean resolve, boolean coreType)
+ {
+ switch (featureID)
+ {
+ case RoomPackage.GENERAL_PROTOCOL_CLASS__ANNOTATIONS:
+ return getAnnotations();
+ }
+ return super.eGet(featureID, resolve, coreType);
+ }
+
+ /**
+ * <!-- begin-user-doc -->
+ * <!-- end-user-doc -->
+ * @generated
+ */
+ @SuppressWarnings("unchecked")
+ @Override
+ public void eSet(int featureID, Object newValue)
+ {
+ switch (featureID)
+ {
+ case RoomPackage.GENERAL_PROTOCOL_CLASS__ANNOTATIONS:
+ getAnnotations().clear();
+ getAnnotations().addAll((Collection<? extends Annotation>)newValue);
+ return;
+ }
+ super.eSet(featureID, newValue);
+ }
+
+ /**
+ * <!-- begin-user-doc -->
+ * <!-- end-user-doc -->
+ * @generated
+ */
+ @Override
+ public void eUnset(int featureID)
+ {
+ switch (featureID)
+ {
+ case RoomPackage.GENERAL_PROTOCOL_CLASS__ANNOTATIONS:
+ getAnnotations().clear();
+ return;
+ }
+ super.eUnset(featureID);
+ }
+
+ /**
+ * <!-- begin-user-doc -->
+ * <!-- end-user-doc -->
+ * @generated
+ */
+ @Override
+ public boolean eIsSet(int featureID)
+ {
+ switch (featureID)
+ {
+ case RoomPackage.GENERAL_PROTOCOL_CLASS__ANNOTATIONS:
+ return annotations != null && !annotations.isEmpty();
+ }
+ return super.eIsSet(featureID);
+ }
+
} //GeneralProtocolClassImpl
diff --git a/plugins/org.eclipse.etrice.core.room/src-gen/org/eclipse/etrice/core/room/impl/RoomPackageImpl.java b/plugins/org.eclipse.etrice.core.room/src-gen/org/eclipse/etrice/core/room/impl/RoomPackageImpl.java
index b5c67fc1d..33d8de06b 100644
--- a/plugins/org.eclipse.etrice.core.room/src-gen/org/eclipse/etrice/core/room/impl/RoomPackageImpl.java
+++ b/plugins/org.eclipse.etrice.core.room/src-gen/org/eclipse/etrice/core/room/impl/RoomPackageImpl.java
@@ -899,7 +899,7 @@ public class RoomPackageImpl extends EPackageImpl implements RoomPackage
* <!-- end-user-doc -->
* @generated
*/
- public EReference getStructureClass_Bindings()
+ public EReference getStructureClass_Annotations()
{
return (EReference)structureClassEClass.getEStructuralFeatures().get(0);
}
@@ -909,7 +909,7 @@ public class RoomPackageImpl extends EPackageImpl implements RoomPackage
* <!-- end-user-doc -->
* @generated
*/
- public EReference getStructureClass_Connections()
+ public EReference getStructureClass_Bindings()
{
return (EReference)structureClassEClass.getEStructuralFeatures().get(1);
}
@@ -919,6 +919,16 @@ public class RoomPackageImpl extends EPackageImpl implements RoomPackage
* <!-- end-user-doc -->
* @generated
*/
+ public EReference getStructureClass_Connections()
+ {
+ return (EReference)structureClassEClass.getEStructuralFeatures().get(2);
+ }
+
+ /**
+ * <!-- begin-user-doc -->
+ * <!-- end-user-doc -->
+ * @generated
+ */
public EClass getActorContainerClass()
{
return actorContainerClassEClass;
@@ -1149,7 +1159,7 @@ public class RoomPackageImpl extends EPackageImpl implements RoomPackage
* <!-- end-user-doc -->
* @generated
*/
- public EReference getDataClass_UserCode1()
+ public EReference getDataClass_Annotations()
{
return (EReference)dataClassEClass.getEStructuralFeatures().get(1);
}
@@ -1159,7 +1169,7 @@ public class RoomPackageImpl extends EPackageImpl implements RoomPackage
* <!-- end-user-doc -->
* @generated
*/
- public EReference getDataClass_UserCode2()
+ public EReference getDataClass_UserCode1()
{
return (EReference)dataClassEClass.getEStructuralFeatures().get(2);
}
@@ -1169,7 +1179,7 @@ public class RoomPackageImpl extends EPackageImpl implements RoomPackage
* <!-- end-user-doc -->
* @generated
*/
- public EReference getDataClass_UserCode3()
+ public EReference getDataClass_UserCode2()
{
return (EReference)dataClassEClass.getEStructuralFeatures().get(3);
}
@@ -1179,7 +1189,7 @@ public class RoomPackageImpl extends EPackageImpl implements RoomPackage
* <!-- end-user-doc -->
* @generated
*/
- public EReference getDataClass_Attributes()
+ public EReference getDataClass_UserCode3()
{
return (EReference)dataClassEClass.getEStructuralFeatures().get(4);
}
@@ -1189,7 +1199,7 @@ public class RoomPackageImpl extends EPackageImpl implements RoomPackage
* <!-- end-user-doc -->
* @generated
*/
- public EReference getDataClass_Operations()
+ public EReference getDataClass_Attributes()
{
return (EReference)dataClassEClass.getEStructuralFeatures().get(5);
}
@@ -1199,6 +1209,16 @@ public class RoomPackageImpl extends EPackageImpl implements RoomPackage
* <!-- end-user-doc -->
* @generated
*/
+ public EReference getDataClass_Operations()
+ {
+ return (EReference)dataClassEClass.getEStructuralFeatures().get(6);
+ }
+
+ /**
+ * <!-- begin-user-doc -->
+ * <!-- end-user-doc -->
+ * @generated
+ */
public EClass getAttribute()
{
return attributeEClass;
@@ -1369,6 +1389,16 @@ public class RoomPackageImpl extends EPackageImpl implements RoomPackage
* <!-- end-user-doc -->
* @generated
*/
+ public EReference getGeneralProtocolClass_Annotations()
+ {
+ return (EReference)generalProtocolClassEClass.getEStructuralFeatures().get(0);
+ }
+
+ /**
+ * <!-- begin-user-doc -->
+ * <!-- end-user-doc -->
+ * @generated
+ */
public EClass getProtocolClass()
{
return protocolClassEClass;
@@ -1769,7 +1799,7 @@ public class RoomPackageImpl extends EPackageImpl implements RoomPackage
* <!-- end-user-doc -->
* @generated
*/
- public EReference getActorClass_GeneralAnnotations()
+ public EReference getActorClass_IfPorts()
{
return (EReference)actorClassEClass.getEStructuralFeatures().get(3);
}
@@ -1779,7 +1809,7 @@ public class RoomPackageImpl extends EPackageImpl implements RoomPackage
* <!-- end-user-doc -->
* @generated
*/
- public EReference getActorClass_IfPorts()
+ public EReference getActorClass_StructureDocu()
{
return (EReference)actorClassEClass.getEStructuralFeatures().get(4);
}
@@ -1789,7 +1819,7 @@ public class RoomPackageImpl extends EPackageImpl implements RoomPackage
* <!-- end-user-doc -->
* @generated
*/
- public EReference getActorClass_StructureDocu()
+ public EReference getActorClass_IntPorts()
{
return (EReference)actorClassEClass.getEStructuralFeatures().get(5);
}
@@ -1799,7 +1829,7 @@ public class RoomPackageImpl extends EPackageImpl implements RoomPackage
* <!-- end-user-doc -->
* @generated
*/
- public EReference getActorClass_IntPorts()
+ public EReference getActorClass_ExtPorts()
{
return (EReference)actorClassEClass.getEStructuralFeatures().get(6);
}
@@ -1809,7 +1839,7 @@ public class RoomPackageImpl extends EPackageImpl implements RoomPackage
* <!-- end-user-doc -->
* @generated
*/
- public EReference getActorClass_ExtPorts()
+ public EReference getActorClass_ServiceImplementations()
{
return (EReference)actorClassEClass.getEStructuralFeatures().get(7);
}
@@ -1819,7 +1849,7 @@ public class RoomPackageImpl extends EPackageImpl implements RoomPackage
* <!-- end-user-doc -->
* @generated
*/
- public EReference getActorClass_ServiceImplementations()
+ public EReference getActorClass_StrSAPs()
{
return (EReference)actorClassEClass.getEStructuralFeatures().get(8);
}
@@ -1829,7 +1859,7 @@ public class RoomPackageImpl extends EPackageImpl implements RoomPackage
* <!-- end-user-doc -->
* @generated
*/
- public EReference getActorClass_StrSAPs()
+ public EReference getActorClass_Attributes()
{
return (EReference)actorClassEClass.getEStructuralFeatures().get(9);
}
@@ -1839,7 +1869,7 @@ public class RoomPackageImpl extends EPackageImpl implements RoomPackage
* <!-- end-user-doc -->
* @generated
*/
- public EReference getActorClass_Attributes()
+ public EReference getActorClass_BehaviorDocu()
{
return (EReference)actorClassEClass.getEStructuralFeatures().get(10);
}
@@ -1849,7 +1879,7 @@ public class RoomPackageImpl extends EPackageImpl implements RoomPackage
* <!-- end-user-doc -->
* @generated
*/
- public EReference getActorClass_BehaviorDocu()
+ public EReference getActorClass_BehaviorAnnotations()
{
return (EReference)actorClassEClass.getEStructuralFeatures().get(11);
}
@@ -1859,19 +1889,9 @@ public class RoomPackageImpl extends EPackageImpl implements RoomPackage
* <!-- end-user-doc -->
* @generated
*/
- public EReference getActorClass_Annotations()
- {
- return (EReference)actorClassEClass.getEStructuralFeatures().get(12);
- }
-
- /**
- * <!-- begin-user-doc -->
- * <!-- end-user-doc -->
- * @generated
- */
public EReference getActorClass_Operations()
{
- return (EReference)actorClassEClass.getEStructuralFeatures().get(13);
+ return (EReference)actorClassEClass.getEStructuralFeatures().get(12);
}
/**
@@ -1881,7 +1901,7 @@ public class RoomPackageImpl extends EPackageImpl implements RoomPackage
*/
public EReference getActorClass_StateMachine()
{
- return (EReference)actorClassEClass.getEStructuralFeatures().get(14);
+ return (EReference)actorClassEClass.getEStructuralFeatures().get(13);
}
/**
@@ -3211,6 +3231,7 @@ public class RoomPackageImpl extends EPackageImpl implements RoomPackage
createEReference(roomClassEClass, ROOM_CLASS__DOCU);
structureClassEClass = createEClass(STRUCTURE_CLASS);
+ createEReference(structureClassEClass, STRUCTURE_CLASS__ANNOTATIONS);
createEReference(structureClassEClass, STRUCTURE_CLASS__BINDINGS);
createEReference(structureClassEClass, STRUCTURE_CLASS__CONNECTIONS);
@@ -3244,6 +3265,7 @@ public class RoomPackageImpl extends EPackageImpl implements RoomPackage
dataClassEClass = createEClass(DATA_CLASS);
createEReference(dataClassEClass, DATA_CLASS__BASE);
+ createEReference(dataClassEClass, DATA_CLASS__ANNOTATIONS);
createEReference(dataClassEClass, DATA_CLASS__USER_CODE1);
createEReference(dataClassEClass, DATA_CLASS__USER_CODE2);
createEReference(dataClassEClass, DATA_CLASS__USER_CODE3);
@@ -3271,6 +3293,7 @@ public class RoomPackageImpl extends EPackageImpl implements RoomPackage
createEReference(portOperationEClass, PORT_OPERATION__SENDS_MSG);
generalProtocolClassEClass = createEClass(GENERAL_PROTOCOL_CLASS);
+ createEReference(generalProtocolClassEClass, GENERAL_PROTOCOL_CLASS__ANNOTATIONS);
protocolClassEClass = createEClass(PROTOCOL_CLASS);
createEAttribute(protocolClassEClass, PROTOCOL_CLASS__COMM_TYPE);
@@ -3322,7 +3345,6 @@ public class RoomPackageImpl extends EPackageImpl implements RoomPackage
createEAttribute(actorClassEClass, ACTOR_CLASS__ABSTRACT);
createEAttribute(actorClassEClass, ACTOR_CLASS__COMM_TYPE);
createEReference(actorClassEClass, ACTOR_CLASS__BASE);
- createEReference(actorClassEClass, ACTOR_CLASS__GENERAL_ANNOTATIONS);
createEReference(actorClassEClass, ACTOR_CLASS__IF_PORTS);
createEReference(actorClassEClass, ACTOR_CLASS__STRUCTURE_DOCU);
createEReference(actorClassEClass, ACTOR_CLASS__INT_PORTS);
@@ -3331,7 +3353,7 @@ public class RoomPackageImpl extends EPackageImpl implements RoomPackage
createEReference(actorClassEClass, ACTOR_CLASS__STR_SA_PS);
createEReference(actorClassEClass, ACTOR_CLASS__ATTRIBUTES);
createEReference(actorClassEClass, ACTOR_CLASS__BEHAVIOR_DOCU);
- createEReference(actorClassEClass, ACTOR_CLASS__ANNOTATIONS);
+ createEReference(actorClassEClass, ACTOR_CLASS__BEHAVIOR_ANNOTATIONS);
createEReference(actorClassEClass, ACTOR_CLASS__OPERATIONS);
createEReference(actorClassEClass, ACTOR_CLASS__STATE_MACHINE);
@@ -3611,6 +3633,7 @@ public class RoomPackageImpl extends EPackageImpl implements RoomPackage
initEReference(getRoomClass_Docu(), this.getDocumentation(), null, "docu", null, 0, 1, RoomClass.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
initEClass(structureClassEClass, StructureClass.class, "StructureClass", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);
+ initEReference(getStructureClass_Annotations(), this.getAnnotation(), null, "annotations", null, 0, -1, StructureClass.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
initEReference(getStructureClass_Bindings(), this.getBinding(), null, "bindings", null, 0, -1, StructureClass.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
initEReference(getStructureClass_Connections(), this.getLayerConnection(), null, "connections", null, 0, -1, StructureClass.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
@@ -3644,6 +3667,7 @@ public class RoomPackageImpl extends EPackageImpl implements RoomPackage
initEClass(dataClassEClass, DataClass.class, "DataClass", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);
initEReference(getDataClass_Base(), this.getDataClass(), null, "base", null, 0, 1, DataClass.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_COMPOSITE, IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
+ initEReference(getDataClass_Annotations(), this.getAnnotation(), null, "annotations", null, 0, -1, DataClass.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
initEReference(getDataClass_UserCode1(), this.getDetailCode(), null, "userCode1", null, 0, 1, DataClass.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
initEReference(getDataClass_UserCode2(), this.getDetailCode(), null, "userCode2", null, 0, 1, DataClass.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
initEReference(getDataClass_UserCode3(), this.getDetailCode(), null, "userCode3", null, 0, 1, DataClass.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
@@ -3671,6 +3695,7 @@ public class RoomPackageImpl extends EPackageImpl implements RoomPackage
initEReference(getPortOperation_SendsMsg(), this.getMessage(), null, "sendsMsg", null, 0, 1, PortOperation.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_COMPOSITE, IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
initEClass(generalProtocolClassEClass, GeneralProtocolClass.class, "GeneralProtocolClass", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);
+ initEReference(getGeneralProtocolClass_Annotations(), this.getAnnotation(), null, "annotations", null, 0, -1, GeneralProtocolClass.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
initEClass(protocolClassEClass, ProtocolClass.class, "ProtocolClass", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);
initEAttribute(getProtocolClass_CommType(), this.getCommunicationType(), "commType", null, 0, 1, ProtocolClass.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
@@ -3722,7 +3747,6 @@ public class RoomPackageImpl extends EPackageImpl implements RoomPackage
initEAttribute(getActorClass_Abstract(), ecorePackage.getEBoolean(), "abstract", null, 0, 1, ActorClass.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
initEAttribute(getActorClass_CommType(), this.getActorCommunicationType(), "commType", null, 0, 1, ActorClass.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
initEReference(getActorClass_Base(), this.getActorClass(), null, "base", null, 0, 1, ActorClass.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_COMPOSITE, IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
- initEReference(getActorClass_GeneralAnnotations(), this.getAnnotation(), null, "generalAnnotations", null, 0, -1, ActorClass.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
initEReference(getActorClass_IfPorts(), this.getPort(), null, "ifPorts", null, 0, -1, ActorClass.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
initEReference(getActorClass_StructureDocu(), this.getDocumentation(), null, "structureDocu", null, 0, 1, ActorClass.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
initEReference(getActorClass_IntPorts(), this.getPort(), null, "intPorts", null, 0, -1, ActorClass.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
@@ -3731,7 +3755,7 @@ public class RoomPackageImpl extends EPackageImpl implements RoomPackage
initEReference(getActorClass_StrSAPs(), this.getSAPRef(), null, "strSAPs", null, 0, -1, ActorClass.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
initEReference(getActorClass_Attributes(), this.getAttribute(), null, "attributes", null, 0, -1, ActorClass.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
initEReference(getActorClass_BehaviorDocu(), this.getDocumentation(), null, "behaviorDocu", null, 0, 1, ActorClass.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
- initEReference(getActorClass_Annotations(), this.getAnnotation(), null, "annotations", null, 0, -1, ActorClass.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
+ initEReference(getActorClass_BehaviorAnnotations(), this.getAnnotation(), null, "behaviorAnnotations", null, 0, -1, ActorClass.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
initEReference(getActorClass_Operations(), this.getStandardOperation(), null, "operations", null, 0, -1, ActorClass.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
initEReference(getActorClass_StateMachine(), this.getStateGraph(), null, "stateMachine", null, 0, 1, ActorClass.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
diff --git a/plugins/org.eclipse.etrice.core.room/src-gen/org/eclipse/etrice/core/room/impl/StructureClassImpl.java b/plugins/org.eclipse.etrice.core.room/src-gen/org/eclipse/etrice/core/room/impl/StructureClassImpl.java
index 615ed6dfc..059eb1bf3 100644
--- a/plugins/org.eclipse.etrice.core.room/src-gen/org/eclipse/etrice/core/room/impl/StructureClassImpl.java
+++ b/plugins/org.eclipse.etrice.core.room/src-gen/org/eclipse/etrice/core/room/impl/StructureClassImpl.java
@@ -18,6 +18,7 @@ import org.eclipse.emf.ecore.InternalEObject;
import org.eclipse.emf.ecore.util.EObjectContainmentEList;
import org.eclipse.emf.ecore.util.InternalEList;
+import org.eclipse.etrice.core.room.Annotation;
import org.eclipse.etrice.core.room.Binding;
import org.eclipse.etrice.core.room.LayerConnection;
import org.eclipse.etrice.core.room.RoomPackage;
@@ -30,6 +31,7 @@ import org.eclipse.etrice.core.room.StructureClass;
* <p>
* The following features are implemented:
* <ul>
+ * <li>{@link org.eclipse.etrice.core.room.impl.StructureClassImpl#getAnnotations <em>Annotations</em>}</li>
* <li>{@link org.eclipse.etrice.core.room.impl.StructureClassImpl#getBindings <em>Bindings</em>}</li>
* <li>{@link org.eclipse.etrice.core.room.impl.StructureClassImpl#getConnections <em>Connections</em>}</li>
* </ul>
@@ -40,6 +42,16 @@ import org.eclipse.etrice.core.room.StructureClass;
public class StructureClassImpl extends RoomClassImpl implements StructureClass
{
/**
+ * The cached value of the '{@link #getAnnotations() <em>Annotations</em>}' containment reference list.
+ * <!-- begin-user-doc -->
+ * <!-- end-user-doc -->
+ * @see #getAnnotations()
+ * @generated
+ * @ordered
+ */
+ protected EList<Annotation> annotations;
+
+ /**
* The cached value of the '{@link #getBindings() <em>Bindings</em>}' containment reference list.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
@@ -85,6 +97,20 @@ public class StructureClassImpl extends RoomClassImpl implements StructureClass
* <!-- end-user-doc -->
* @generated
*/
+ public EList<Annotation> getAnnotations()
+ {
+ if (annotations == null)
+ {
+ annotations = new EObjectContainmentEList<Annotation>(Annotation.class, this, RoomPackage.STRUCTURE_CLASS__ANNOTATIONS);
+ }
+ return annotations;
+ }
+
+ /**
+ * <!-- begin-user-doc -->
+ * <!-- end-user-doc -->
+ * @generated
+ */
public EList<Binding> getBindings()
{
if (bindings == null)
@@ -118,6 +144,8 @@ public class StructureClassImpl extends RoomClassImpl implements StructureClass
{
switch (featureID)
{
+ case RoomPackage.STRUCTURE_CLASS__ANNOTATIONS:
+ return ((InternalEList<?>)getAnnotations()).basicRemove(otherEnd, msgs);
case RoomPackage.STRUCTURE_CLASS__BINDINGS:
return ((InternalEList<?>)getBindings()).basicRemove(otherEnd, msgs);
case RoomPackage.STRUCTURE_CLASS__CONNECTIONS:
@@ -136,6 +164,8 @@ public class StructureClassImpl extends RoomClassImpl implements StructureClass
{
switch (featureID)
{
+ case RoomPackage.STRUCTURE_CLASS__ANNOTATIONS:
+ return getAnnotations();
case RoomPackage.STRUCTURE_CLASS__BINDINGS:
return getBindings();
case RoomPackage.STRUCTURE_CLASS__CONNECTIONS:
@@ -155,6 +185,10 @@ public class StructureClassImpl extends RoomClassImpl implements StructureClass
{
switch (featureID)
{
+ case RoomPackage.STRUCTURE_CLASS__ANNOTATIONS:
+ getAnnotations().clear();
+ getAnnotations().addAll((Collection<? extends Annotation>)newValue);
+ return;
case RoomPackage.STRUCTURE_CLASS__BINDINGS:
getBindings().clear();
getBindings().addAll((Collection<? extends Binding>)newValue);
@@ -177,6 +211,9 @@ public class StructureClassImpl extends RoomClassImpl implements StructureClass
{
switch (featureID)
{
+ case RoomPackage.STRUCTURE_CLASS__ANNOTATIONS:
+ getAnnotations().clear();
+ return;
case RoomPackage.STRUCTURE_CLASS__BINDINGS:
getBindings().clear();
return;
@@ -197,6 +234,8 @@ public class StructureClassImpl extends RoomClassImpl implements StructureClass
{
switch (featureID)
{
+ case RoomPackage.STRUCTURE_CLASS__ANNOTATIONS:
+ return annotations != null && !annotations.isEmpty();
case RoomPackage.STRUCTURE_CLASS__BINDINGS:
return bindings != null && !bindings.isEmpty();
case RoomPackage.STRUCTURE_CLASS__CONNECTIONS:

Back to the top
diff --git a/plugins/org.eclipse.etrice.core.room/src-gen/org/eclipse/etrice/core/room/impl/ActorClassImpl.java b/plugins/org.eclipse.etrice.core.room/src-gen/org/eclipse/etrice/core/room/impl/ActorClassImpl.java
index 4588df636..836603ca0 100644
--- a/plugins/org.eclipse.etrice.core.room/src-gen/org/eclipse/etrice/core/room/impl/ActorClassImpl.java
+++ b/plugins/org.eclipse.etrice.core.room/src-gen/org/eclipse/etrice/core/room/impl/ActorClassImpl.java
@@ -44,7 +44,6 @@ import org.eclipse.etrice.core.room.StateGraph;
* <li>{@link org.eclipse.etrice.core.room.impl.ActorClassImpl#isAbstract <em>Abstract</em>}</li>
* <li>{@link org.eclipse.etrice.core.room.impl.ActorClassImpl#getCommType <em>Comm Type</em>}</li>
* <li>{@link org.eclipse.etrice.core.room.impl.ActorClassImpl#getBase <em>Base</em>}</li>
- * <li>{@link org.eclipse.etrice.core.room.impl.ActorClassImpl#getGeneralAnnotations <em>General Annotations</em>}</li>
* <li>{@link org.eclipse.etrice.core.room.impl.ActorClassImpl#getIfPorts <em>If Ports</em>}</li>
* <li>{@link org.eclipse.etrice.core.room.impl.ActorClassImpl#getStructureDocu <em>Structure Docu</em>}</li>
* <li>{@link org.eclipse.etrice.core.room.impl.ActorClassImpl#getIntPorts <em>Int Ports</em>}</li>
@@ -53,7 +52,7 @@ import org.eclipse.etrice.core.room.StateGraph;
* <li>{@link org.eclipse.etrice.core.room.impl.ActorClassImpl#getStrSAPs <em>Str SA Ps</em>}</li>
* <li>{@link org.eclipse.etrice.core.room.impl.ActorClassImpl#getAttributes <em>Attributes</em>}</li>
* <li>{@link org.eclipse.etrice.core.room.impl.ActorClassImpl#getBehaviorDocu <em>Behavior Docu</em>}</li>
- * <li>{@link org.eclipse.etrice.core.room.impl.ActorClassImpl#getAnnotations <em>Annotations</em>}</li>
+ * <li>{@link org.eclipse.etrice.core.room.impl.ActorClassImpl#getBehaviorAnnotations <em>Behavior Annotations</em>}</li>
* <li>{@link org.eclipse.etrice.core.room.impl.ActorClassImpl#getOperations <em>Operations</em>}</li>
* <li>{@link org.eclipse.etrice.core.room.impl.ActorClassImpl#getStateMachine <em>State Machine</em>}</li>
* </ul>
@@ -114,16 +113,6 @@ public class ActorClassImpl extends ActorContainerClassImpl implements ActorClas
protected ActorClass base;
/**
- * The cached value of the '{@link #getGeneralAnnotations() <em>General Annotations</em>}' containment reference list.
- * <!-- begin-user-doc -->
- * <!-- end-user-doc -->
- * @see #getGeneralAnnotations()
- * @generated
- * @ordered
- */
- protected EList<Annotation> generalAnnotations;
-
- /**
* The cached value of the '{@link #getIfPorts() <em>If Ports</em>}' containment reference list.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
@@ -204,14 +193,14 @@ public class ActorClassImpl extends ActorContainerClassImpl implements ActorClas
protected Documentation behaviorDocu;
/**
* The cached value of the '{@link #getAnnotations() <em>Annotations</em>}' containment reference list.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
- * @see #getAnnotations()
+ * @see #getBehaviorAnnotations()
* @generated
* @ordered
*/
- protected EList<Annotation> annotations;
+ protected EList<Annotation> behaviorAnnotations;
/**
* The cached value of the '{@link #getOperations() <em>Operations</em>}' containment reference list.
@@ -348,20 +337,6 @@ public class ActorClassImpl extends ActorContainerClassImpl implements ActorClas
* <!-- end-user-doc -->
* @generated
*/
- public EList<Annotation> getGeneralAnnotations()
- {
- if (generalAnnotations == null)
- {
- generalAnnotations = new EObjectContainmentEList<Annotation>(Annotation.class, this, RoomPackage.ACTOR_CLASS__GENERAL_ANNOTATIONS);
- }
- return generalAnnotations;
- }
-
- /**
- * <!-- begin-user-doc -->
- * <!-- end-user-doc -->
- * @generated
- */
public EList<Port> getIfPorts()
{
if (ifPorts == null)
@@ -542,13 +517,13 @@ public class ActorClassImpl extends ActorContainerClassImpl implements ActorClas
* <!-- end-user-doc -->
* @generated
*/
- public EList<Annotation> getAnnotations()
+ public EList<Annotation> getBehaviorAnnotations()
{
- if (annotations == null)
+ if (behaviorAnnotations == null)
{
- annotations = new EObjectContainmentEList<Annotation>(Annotation.class, this, RoomPackage.ACTOR_CLASS__ANNOTATIONS);
+ behaviorAnnotations = new EObjectContainmentEList<Annotation>(Annotation.class, this, RoomPackage.ACTOR_CLASS__BEHAVIOR_ANNOTATIONS);
}
- return annotations;
+ return behaviorAnnotations;
}
/**
@@ -623,8 +598,6 @@ public class ActorClassImpl extends ActorContainerClassImpl implements ActorClas
{
switch (featureID)
{
- case RoomPackage.ACTOR_CLASS__GENERAL_ANNOTATIONS:
- return ((InternalEList<?>)getGeneralAnnotations()).basicRemove(otherEnd, msgs);
case RoomPackage.ACTOR_CLASS__IF_PORTS:
return ((InternalEList<?>)getIfPorts()).basicRemove(otherEnd, msgs);
case RoomPackage.ACTOR_CLASS__STRUCTURE_DOCU:
@@ -641,8 +614,8 @@ public class ActorClassImpl extends ActorContainerClassImpl implements ActorClas
return ((InternalEList<?>)getAttributes()).basicRemove(otherEnd, msgs);
case RoomPackage.ACTOR_CLASS__BEHAVIOR_DOCU:
return basicSetBehaviorDocu(null, msgs);
- case RoomPackage.ACTOR_CLASS__ANNOTATIONS:
- return ((InternalEList<?>)getAnnotations()).basicRemove(otherEnd, msgs);
+ case RoomPackage.ACTOR_CLASS__BEHAVIOR_ANNOTATIONS:
+ return ((InternalEList<?>)getBehaviorAnnotations()).basicRemove(otherEnd, msgs);
case RoomPackage.ACTOR_CLASS__OPERATIONS:
return ((InternalEList<?>)getOperations()).basicRemove(otherEnd, msgs);
case RoomPackage.ACTOR_CLASS__STATE_MACHINE:
@@ -668,8 +641,6 @@ public class ActorClassImpl extends ActorContainerClassImpl implements ActorClas
case RoomPackage.ACTOR_CLASS__BASE:
if (resolve) return getBase();
return basicGetBase();
- case RoomPackage.ACTOR_CLASS__GENERAL_ANNOTATIONS:
- return getGeneralAnnotations();
case RoomPackage.ACTOR_CLASS__IF_PORTS:
return getIfPorts();
case RoomPackage.ACTOR_CLASS__STRUCTURE_DOCU:
@@ -686,8 +657,8 @@ public class ActorClassImpl extends ActorContainerClassImpl implements ActorClas
return getAttributes();
case RoomPackage.ACTOR_CLASS__BEHAVIOR_DOCU:
return getBehaviorDocu();
- case RoomPackage.ACTOR_CLASS__ANNOTATIONS:
- return getAnnotations();
+ case RoomPackage.ACTOR_CLASS__BEHAVIOR_ANNOTATIONS:
+ return getBehaviorAnnotations();
case RoomPackage.ACTOR_CLASS__OPERATIONS:
return getOperations();
case RoomPackage.ACTOR_CLASS__STATE_MACHINE:
@@ -716,10 +687,6 @@ public class ActorClassImpl extends ActorContainerClassImpl implements ActorClas
case RoomPackage.ACTOR_CLASS__BASE:
setBase((ActorClass)newValue);
return;
- case RoomPackage.ACTOR_CLASS__GENERAL_ANNOTATIONS:
- getGeneralAnnotations().clear();
- getGeneralAnnotations().addAll((Collection<? extends Annotation>)newValue);
- return;
case RoomPackage.ACTOR_CLASS__IF_PORTS:
getIfPorts().clear();
getIfPorts().addAll((Collection<? extends Port>)newValue);
@@ -750,9 +717,9 @@ public class ActorClassImpl extends ActorContainerClassImpl implements ActorClas
case RoomPackage.ACTOR_CLASS__BEHAVIOR_DOCU:
setBehaviorDocu((Documentation)newValue);
return;
- case RoomPackage.ACTOR_CLASS__ANNOTATIONS:
- getAnnotations().clear();
- getAnnotations().addAll((Collection<? extends Annotation>)newValue);
+ case RoomPackage.ACTOR_CLASS__BEHAVIOR_ANNOTATIONS:
+ getBehaviorAnnotations().clear();
+ getBehaviorAnnotations().addAll((Collection<? extends Annotation>)newValue);
return;
case RoomPackage.ACTOR_CLASS__OPERATIONS:
getOperations().clear();
@@ -784,9 +751,6 @@ public class ActorClassImpl extends ActorContainerClassImpl implements ActorClas
case RoomPackage.ACTOR_CLASS__BASE:
setBase((ActorClass)null);
return;
- case RoomPackage.ACTOR_CLASS__GENERAL_ANNOTATIONS:
- getGeneralAnnotations().clear();
- return;
case RoomPackage.ACTOR_CLASS__IF_PORTS:
getIfPorts().clear();
return;
@@ -811,8 +775,8 @@ public class ActorClassImpl extends ActorContainerClassImpl implements ActorClas
case RoomPackage.ACTOR_CLASS__BEHAVIOR_DOCU:
setBehaviorDocu((Documentation)null);
return;
- case RoomPackage.ACTOR_CLASS__ANNOTATIONS:
- getAnnotations().clear();
+ case RoomPackage.ACTOR_CLASS__BEHAVIOR_ANNOTATIONS:
+ getBehaviorAnnotations().clear();
return;
case RoomPackage.ACTOR_CLASS__OPERATIONS:
getOperations().clear();
@@ -840,8 +804,6 @@ public class ActorClassImpl extends ActorContainerClassImpl implements ActorClas
return commType != COMM_TYPE_EDEFAULT;
case RoomPackage.ACTOR_CLASS__BASE:
return base != null;
- case RoomPackage.ACTOR_CLASS__GENERAL_ANNOTATIONS:
- return generalAnnotations != null && !generalAnnotations.isEmpty();
case RoomPackage.ACTOR_CLASS__IF_PORTS:
return ifPorts != null && !ifPorts.isEmpty();
case RoomPackage.ACTOR_CLASS__STRUCTURE_DOCU:
@@ -858,8 +820,8 @@ public class ActorClassImpl extends ActorContainerClassImpl implements ActorClas
return attributes != null && !attributes.isEmpty();
case RoomPackage.ACTOR_CLASS__BEHAVIOR_DOCU:
return behaviorDocu != null;
- case RoomPackage.ACTOR_CLASS__ANNOTATIONS:
- return annotations != null && !annotations.isEmpty();
+ case RoomPackage.ACTOR_CLASS__BEHAVIOR_ANNOTATIONS:
+ return behaviorAnnotations != null && !behaviorAnnotations.isEmpty();
case RoomPackage.ACTOR_CLASS__OPERATIONS:
return operations != null && !operations.isEmpty();
case RoomPackage.ACTOR_CLASS__STATE_MACHINE:
@@ -204,14 +193,14 @@ public class ActorClassImpl extends ActorContainerClassImpl implements ActorClas
protected Documentation behaviorDocu;
/**
- * The cached value of the '{@link #getAnnotations() <em>Annotations</em>}' containment reference list.
+ * The cached value of the '{@link #getBehaviorAnnotations() <em>Behavior Annotations</em>}' containment reference list.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->